@@ -1,9 +1,9 @@
 /*
-   $Id: Pg.h,v 1.8 2005/05/23 21:26:07 turnstep Exp $
+   $Id: Pg.h,v 1.14 2006/04/05 14:47:13 turnstep Exp $
 
-   Copyright (c) 2000-2004 PostgreSQL Global Development Group
-   Copyright (c) 1997,1998,1999,2000 Edmund Mergl
-   Portions Copyright (c) 1994,1995,1996,1997 Tim Bunce
+   Copyright (c) 2000-2006 PostgreSQL Global Development Group
+   Copyright (c) 1997-2000 Edmund Mergl
+   Portions Copyright (c) 1994-1997 Tim Bunce
 
    You may distribute under the terms of either the GNU General Public
    License or the Artistic License, as specified in the Perl README file.
@@ -15,6 +15,9 @@
 static int errno;
 #endif
 
+#define DBDPG_TRUE (bool)1
+#define DBDPG_FALSE (bool)0
+
 #include "libpq-fe.h"
 
 #ifdef NEVER
@@ -28,11 +31,6 @@ static int errno;
 #define INV_WRITE 0x00020000
 #endif
 
-/* For versions of DBI older than 1.41 */
-#ifndef DBIcf_Executed
-#define DBIcf_Executed 0x080000
-#endif
-
 #ifdef BUFSIZ
 #undef BUFSIZ
 #endif
@@ -44,15 +42,15 @@ static int errno;
 
 #include <DBIXS.h>		/* installed by the DBI module	*/
 
-#include "dbdimp.h"		/* read in our implementation details */
-
-#include "quote.h"		/* read in our implementation details */
-
 #include <dbd_xsh.h>		/* installed by the DBI module	*/
 
+#include "dbdimp.h"
+#include "quote.h"
+#include "types.h"
 
 /* defines for Driver.xst to let it know what functions to include */
 #define dbd_st_rows dbd_st_rows
 #define dbd_discon_all dbd_discon_all
+#define dbd_st_fetchrow_hashref valid
 
 /* end of Pg.h */
